function [xx,tt] = lamperti_trans(yy,H,samplingmode,q) ;

% Lamperti transformation
% [xx,tt] = lamperti_trans(yy,H,samplingmode,q) ;
%
% INPUT	yy = signal to transform (stationnary world)
%	H = similarity exponent
%	samplingmode = sampling of yy (default 'l', q=1)
%		some vector to specify the sampling instant of yy
%		'a' for arithmetical samplig of yy, with step q (q*(1:N))
%		'g' for geometric sampling (q.^(1:N))
%		'l' for logarihmic sampling (log(q*(1:N))
%  (warning: 'g' is not a logical choice)
%
% OUTPUT xx = Lamperti image of yy
%	tt = sampling times for xx
%
% (pborgnat 2002)

% definition of sampling
N=length(yy);
if nargin==2, 
	samplingmode='l' ; q=1;
end;

if (nargin==3),
if samplingmode=='a', 
	uu=1:N; 
elseif samplingmode=='g', 
	q=input('Enter the geometric sampling ratio, q = ? ');
	uu=q.^(1:N);
elseif samplingmode=='l', 
	uu=log(1:N); q=[]; 
elseif (length(samplingmode)>1)
	uu=samplingmode; q=[];
end;
end;

if length(q)==1,
	if samplingmode=='a', uu=q*(1:N); end;
	if samplingmode=='g', uu=q.^(1:N); end;
	if samplingmode=='l', uu=log(q*(1:N)); end;
end;

% transformation
tt=exp(uu);
xx=exp(H*uu).*yy ;


