function [Mellin,beta,Q,Kmin,Nb,Mmin]=mellin_gtrans(yy,r,elog,Nb,Q,dispflag);

% Discrete Mellin transform for geometrically sampled signal
% [Mellin,beta,Q,Kmin,Nb,Mmin,elog,yyelog]=mellin_gtrans(yy,r,elog,Nb,Q,dispflag);
%
% Algorithm from Bertrand, Bertrand and Ovarlez
% INPUT yy = analysed signal (geometrical sampling)
%       r = amplitude parameter (take r=-H-1)
%       elog = geometrical sampling vector
%       Nb = number of points for beta (opt.)
%       Q = coefficient for sampling step of the Mellin transform (opt.)
%       dispflag = set to 'n' to skip warnings (opt.)
%
% OUTPUT Mellin = discrete Mellin transform of yy
%       beta = Mellin scale variable vector
%       Q = 1/log(Q) is the sampling step for Mellin scale variable
%       Kmin = first index of the sampled beta's
%       Nb = number of points for beta
%       Mmin =  min. index for the geometrical sampling of yy (in q^n)
%
% This is a non interactive version of Mellin transform.
%
% pborgnat (february 2000)
%

% Commentaires en franais
%% Transformee de Mellin discrete - signal en serie geometrique
%Algorithme selon Bertrand et al.
%INPUT: yy = signal a analyser donn sur chantillonnage gomtrique q^n
%       r = parametre du groupe de dilatation
%       elog = vecteurs de la sie gomtrique
%       Q = pas d'echantillonnage pour Mellin
%       dispflag = 'n' enleve les warning
%OUTPUT: Mellin = transf de Mellin discrete
%        beta = variable de Mellin echantillonnee
%        Q = rapport de periodisation par dilatation ; pas en Mellin =  1/ln(Q)
%        Kmin = indice min des beta echantillonnes
%        Nb = nombre de points en beta
%        Mmin = indice min de l'echantillonnage log (en q^n)
%        elog = vecteur des Nb pts d'echantillonnage log
%        yyelog = signal reechantillonne geometriquement
%
%Version non interactive. 
%
%(pborgnat fevrier 2000)

if nargin<6, dispflag='y' ; end ; 
[yrow,ycol] = size(yy) ;
if yrow ~= 1, yy = yy' ; end ;
N = length(yy) ;
%% N est le nbre de points en temps du signal entre %%

%% Choix des parametres d'echantillonnage

%% procedure pour trouver [F1 F2] support de YY... => DF %%
%% et [V1 V2] support de yy... => Q_min %%
%approche simplifiee ; on utilise la variable temporelle v = t/\tau_e 
%V1 = 1 ;
%V0 = 1-V1 ; %indice, evt non entier, de la position du zero en temps.
Ny = N ;
% Ny nbre de points utilises dans l'analyse 
%V2 = Ny+V1-1 ; %borne max du support temporel ;
Ny2 = Ny*2 ;  %longueur du signal unilateral a analyser ;
%%ou pour un signal unilateral => borne max temporelle du signal a analyser =
%Ny2 = Ny*2 ;
%V2 = Ny2+V1-1 ;
V1=elog(1); V2=elog(end);
if nargin<5, 
  Q = V2/V1 ;
%else
%  if Q<(V2/V1),
%  warnQ = ['Warning, Q is too small (Qmin = ',num2str(V2/V1),').'] ;
%  if dispflag=='n', warnQ = []; end ;
%    disp(warnQ) ;
%  end ;
%  V2 = V1*Q ;   %V2 effectif de l'analyse
end ;

fyy = yy ;
%fyy = [yy(1:Ny) zeros(1,Ny)] ;
% interpretation freq. : prendre fftshift(fyy) %%
% interpretation temporelle : on rajoute des 0 aux temps negatifs => unilateral %%
%YY = ifft(fyy)*Ny2 ;
%% YY est analytique et fft(fyy) = Ny2*fliplr(YY)([Ny2 1:Ny2-1]) %%
%% inversement : FT(YY) = [zeros(1,V2) yy] *Ny2 ;

%choix de DF
%fmin=0. ; fmax=0.5 ;
%DF = fmax-fmin ;

%Q_min = V2/V1 ;
%Nb_min = fix(V2*DF*log(Q)) ;
 %% condition de bon echantillonnage pour Mellin discrete
%Nbsp = 2^nextpow2(Nb_min) ;
%% choix de Nb
if nargin<4,
  Nb = N ;
%else, 
%  if Nb<Nb_min, 
%    warnNb = ['Warning, Nb is to small (Nbmin = ',num2str(Nb_min),').'] ;
%    if dispflag=='n', warnNb = [] ; end ;
%    disp(warnNb) ;
%  end ;
end ;

% d'ou les parametres d'echantillonnage
beta0 = Nb/2/log(Q) ;
q = Q.^(1./Nb) ;  %% NE PAS UTILISER ; PB d'arrondi numerique !!!
logq = log(Q)/Nb ;
Mmin = ceil(log(V1)/logq) ;

%% echantillonnage logarithmique en q^n
nn = (1:Nb) + Mmin-1 ;
%elog = exp(logq.*nn) ; % instants q^nn 

% methode par interpolation INUTILE ICI ; echantillnnage correct en entree
%eind_sup=ceil(elog-V1+1);   %indices
%eind_inf=fix(elog-V1+1);
%einf = fix(elog);  %vrai instant
%emax = max(eind_sup) ;
%if emax>Ny,
%  fyy((Ny+1):emax) = zeros(1,emax-Ny) ;
%end ;
%yyelog=(fyy(eind_sup)-fyy(eind_inf)).*(elog-einf)+fyy(eind_inf);
%yyelog=yyelog/mellin_NormR(yyelog,elog,r)*mellin_NormR(yy,V1:V2,r) ;
% normalisation de telle sorte que la serie geom ait la meme norme que depart
yyelog=yy;
 
% methode par reconstruction en Fourier... (a faire) 

%%echantillonnage lineaire en beta
Kmin = ceil(-beta0*log(Q)) ;
k = (0:Nb-1) + Kmin*ones(1,Nb) ;
beta = k/log(Q) ;

%% transformee discrete de mellin
mm=1:Nb ;
ampl = (r+1)*logq ;
cor_phase = (2*pi*i*Kmin/Nb) ;
blah = exp(mm*(cor_phase+ ampl)-cor_phase).*yyelog ;
TFblah = Nb*logq*exp((Mmin-1)*ampl)*(ifft(blah)) ;
Mellin = TFblah.*exp(2*pi*i*Mmin*k/Nb) ; 


%% Verifier la normalisation
V = linspace(V1,V1+Ny-1,Ny) ;
expnorm = 2*r+1 ;
%normR_sig2 = (yy)*(yy.*V.^expnorm)' ;
normR_sig2=mellin_NormR(yyelog,elog,r).^2; 
%normalisation pour retrouver les amplitudes (et non norme) par reconstruction.
Mellin = sqrt(normR_sig2)*logq*sqrt(log(Q))/norm(Mellin)*Mellin ;
  

