% Lomb Periodogram 
% function [per,px]=plomb(x,y,ofac,hifac) ;
%
% Algorithm from Press et al., "Numerical recipes in C"
% Periodogram for an unevenly sampled signal y(x).
% INPUT	x = time vector
%	y = signal vector
%	ofac = oversampling factor (typical 4)
%	hifac = multiplicative factor for highest frequency (typical 2)
%
% OUTPUT per = periodogram
%	px = frequencies vector 
%
% pborgnat (november 2000)


%  Programme de l'algo (on rapide) donne par Press et al.,
% "Numerical recipes in C"
%
% inputs : signal y(x); 
% typical values ofac=4; hifac=2;
%pborgnat nov 2000

function [per,px]=per_lomb(x,y,ofac,hifac) ;

N=length(x) ; 
Nout=0.5*ofac*hifac*N ;
xmin=min(x) ; xmax=max(x) ;
xdif=xmax-xmin ;
yave=mean(y) ;
yvar=var(y) ;
xmoy=xmin+xdif/2 ;

pymax=0 ;
pnow=1.0/(xdif*ofac) ;
%for jj=1:N,
arg=(x-xmoy)*pnow ;
wpr=-2*(sin(0.5*arg)).^2 ;
wpi=sin(arg) ;
wr=cos(arg) ;
wi=wpi ;
yy=y-yave ;

px=[]; per=[] ; 
for ii=1:Nout,
  px(ii)=pnow ;
  sumsh=sum(wr.*wi) ;
  sumc=sum(wr.^2-wi.^2) ;
  wtau=0.5*atan2(2.0*sumsh,sumc) ;
 % for jj=1:N,
  ss=(wi.*cos(wtau)-wr.*sin(wtau)) ;
  cc=(wr.*cos(wtau)-wi.*sin(wtau)) ;
  sumsy=sum(ss.*yy) ;
  sumcy=sum(cc.*yy) ;
  sums=sum(ss.^2) ;
  sumc=sum(cc.^2) ;
  wtmp=wr.*wpr-wi.*wpi+wr ;
  wi=wi.*wpr+wr.*wpi+wi ;
  wr=wtmp ;
% sur wr et wi
  per(ii)=0.5*(sumcy.*sumcy./sumc+sumsy.*sumsy./sums)/yvar ;
  pnow=pnow+1.0/(ofac*xdif) ;
  pymax=max(pymax,pnow) ;
end ;

px=px/2/pi ;  % on se ramene en frequence et non en pulsation


